# bismuthsdk

[![PyPI - Version](https://img.shields.io/pypi/v/bismuthsdk.svg)](https://pypi.org/project/bismuthsdk)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/bismuthsdk.svg)](https://pypi.org/project/bismuthsdk)

-----

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)

## Installation

```console
pip install bismuthsdk
```

## Usage

Log in to the Bismuth web UI and create an API key [here](https://app.bismuth.cloud/settings/apikeys).

Then see the [examples directory](./examples) for usage of this SDK.
